==> quanyi-center-api-1.0.9-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/RemoteUploadTaskService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.common.UploadTaskDto;
import cn.com.duiba.quanyi.center.api.param.UploadTaskSaveParam;
import cn.com.duiba.quanyi.center.api.param.UploadTaskSearchParam;
import cn.com.duiba.quanyi.center.api.param.UploadTaskUpdateResultParam;

import java.util.List;

/**
 * 上传任务表 服务类
 * @author lizhi
 * @date 2023/8/4 17:29
 */
@AdvancedFeignClient
public interface RemoteUploadTaskService {

    /**
     * 根据条件查询，不分页
     * @param param 查询条件
     * @return 上传任务集合
     */
    List<UploadTaskDto> selectPage(UploadTaskSearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(UploadTaskSearchParam param);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 上传任务
     */
    UploadTaskDto selectById(Long id);


    /**
     * 保存上传任务
     * @param param 保存参数
     * @return 任务ID
     */
    Long saveTask(UploadTaskSaveParam param);

    /**
     * 更改任务状态
     * @param id 主键
     * @param status 要更改为的状态
     *               {@link cn.com.duiba.quanyi.center.api.enums.UploadTaskStatusEnum}
     * @return 执行结果
     */
    int updateTaskStatus(Long id, Integer status);

    /**
     * 更新上传结果
     * @param param 上传结果
     * @return 执行结果
     */
    int updateResult(UploadTaskUpdateResultParam param);

    /**
     * 根据主键批量查询
     * @param ids 主键集合
     * @return 上传任务集合
     */
    List<UploadTaskDto> selectByIds(List<Long> ids);
}

==> quanyi-center-api-1.3.34-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/RemoteUploadTaskService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.common.UploadTaskDto;
import cn.com.duiba.quanyi.center.api.param.UploadTaskSaveParam;
import cn.com.duiba.quanyi.center.api.param.UploadTaskSearchParam;
import cn.com.duiba.quanyi.center.api.param.UploadTaskUpdateResultParam;

import java.util.List;

/**
 * 上传任务表 服务类
 * @author lizhi
 * @date 2023/8/4 17:29
 */
@AdvancedFeignClient
public interface RemoteUploadTaskService {

    /**
     * 根据条件查询，不分页
     * @param param 查询条件
     * @return 上传任务集合
     */
    List<UploadTaskDto> selectPage(UploadTaskSearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(UploadTaskSearchParam param);

    /**
     * 查询业务类型下，文件名数量
     * @param bizType 业务类型
     * @see cn.com.duiba.quanyi.center.api.enums.UploadBizTypeEnum
     * @param fileName 文件名
     * @return 数量
     */
    long selectFileNameCount(Integer bizType, String fileName);

    /**
     * 查询业务类型下+渠道下，文件名成功导入的记录数量
     * @param bizType 业务类型
     * @see cn.com.duiba.quanyi.center.api.enums.UploadBizTypeEnum
     * @param bizId 业务ID
     * @param fileName 文件名
     * @return 数量
     */
    long selectFileNameSuccessCount(Integer bizType,Long bizId, String fileName);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 上传任务
     */
    UploadTaskDto selectById(Long id);


    /**
     * 保存上传任务
     * @param param 保存参数
     * @return 任务ID
     */
    Long saveTask(UploadTaskSaveParam param);

    /**
     * 更改任务状态
     * @param id 主键
     * @param status 要更改为的状态
     *               {@link cn.com.duiba.quanyi.center.api.enums.UploadTaskStatusEnum}
     * @return 执行结果
     */
    int updateTaskStatus(Long id, Integer status);

    /**
     * 增加成功数量
     * @param id 主键
     * @param add 增加数量
     * @return 影响行数
     */
    int addSuccessCount(Long id, int add);

    /**
     * 增加失败数量
     * @param id 主键
     * @param add 增加数量
     * @return 影响行数
     */
    int addFailCount(Long id, int add);

    /**
     * 更新上传结果
     * @param param 上传结果
     * @return 执行结果
     */
    int updateResult(UploadTaskUpdateResultParam param);

    /**
     * 根据主键批量查询
     * @param ids 主键集合
     * @return 上传任务集合
     */
    List<UploadTaskDto> selectByIds(List<Long> ids);
}
